==> stagehand-0.1.1.tar.gz: lib/generators/consoleapp_data.dart <==
// Copyright (c) 2014, Google Inc. Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

List<String> data = [
  ".gitignore",
  "text",
  "LkRTX1N0b3JlCi5pZGVhCi5wdWIvCmJ1aWxkLwpwYWNrYWdlcwpwdWJzcGVjLmxvY2sK",
  "bin/main.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uIEFsbCByaWdodHMgcmVzZXJ2
ZWQuIFVzZSBvZiB0aGlzIHNvdXJjZSBjb2RlCi8vIGlzIGdvdmVybmVkIGJ5IGEgQlNELXN0eWxl
IGxpY2Vuc2UgdGhhdCBjYW4gYmUgZm91bmQgaW4gdGhlIExJQ0VOU0UgZmlsZS4KCmltcG9ydCAn
cGFja2FnZTp7e3Byb2plY3ROYW1lfX0ve3twcm9qZWN0TmFtZX19LmRhcnQnIGFzIHt7cHJvamVj
dE5hbWV9fTsKCm1haW4oKSB7CiAgcHJpbnQoJ0hlbGxvIHdvcmxkIScpOwogIHByaW50KCd2YWx1
ZTogJHt7e3Byb2plY3ROYW1lfX0uY2FsY3VsYXRlKCl9Jyk7Cn0K""",
  "CHANGELOG.md",
  "text",
  "IyBDaGFuZ2Vsb2cKCiMjIDAuMC4xCgoqIEluaXRpYWwgcHJvamVjdCBjcmVhdGlvbgo=",
  "lib/projectName.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uIEFsbCByaWdodHMgcmVzZXJ2
ZWQuIFVzZSBvZiB0aGlzIHNvdXJjZSBjb2RlCi8vIGlzIGdvdmVybmVkIGJ5IGEgQlNELXN0eWxl
IGxpY2Vuc2UgdGhhdCBjYW4gYmUgZm91bmQgaW4gdGhlIExJQ0VOU0UgZmlsZS4KCi8vLyBUaGUg
e3twcm9qZWN0TmFtZX19IGxpYnJhcnkuCmxpYnJhcnkge3twcm9qZWN0TmFtZX19OwoKaW50IGNh
bGN1bGF0ZSgpIHsKICByZXR1cm4gNiAqIDc7Cn0K""",
  "LICENSE",
  "text",
  """Q29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uCkFsbCByaWdodHMgcmVzZXJ2ZWQu
CgpSZWRpc3RyaWJ1dGlvbiBhbmQgdXNlIGluIHNvdXJjZSBhbmQgYmluYXJ5IGZvcm1zLCB3aXRo
IG9yIHdpdGhvdXQKbW9kaWZpY2F0aW9uLCBhcmUgcGVybWl0dGVkIHByb3ZpZGVkIHRoYXQgdGhl
IGZvbGxvd2luZyBjb25kaXRpb25zIGFyZSBtZXQ6CiAgICAqIFJlZGlzdHJpYnV0aW9ucyBvZiBz
b3VyY2UgY29kZSBtdXN0IHJldGFpbiB0aGUgYWJvdmUgY29weXJpZ2h0CiAgICAgIG5vdGljZSwg
dGhpcyBsaXN0IG9mIGNvbmRpdGlvbnMgYW5kIHRoZSBmb2xsb3dpbmcgZGlzY2xhaW1lci4KICAg
ICogUmVkaXN0cmlidXRpb25zIGluIGJpbmFyeSBmb3JtIG11c3QgcmVwcm9kdWNlIHRoZSBhYm92
ZSBjb3B5cmlnaHQKICAgICAgbm90aWNlLCB0aGlzIGxpc3Qgb2YgY29uZGl0aW9ucyBhbmQgdGhl
IGZvbGxvd2luZyBkaXNjbGFpbWVyIGluIHRoZQogICAgICBkb2N1bWVudGF0aW9uIGFuZC9vciBv
dGhlciBtYXRlcmlhbHMgcHJvdmlkZWQgd2l0aCB0aGUgZGlzdHJpYnV0aW9uLgogICAgKiBOZWl0
aGVyIHRoZSBuYW1lIG9mIHRoZSA8b3JnYW5pemF0aW9uPiBub3IgdGhlCiAgICAgIG5hbWVzIG9m
IGl0cyBjb250cmlidXRvcnMgbWF5IGJlIHVzZWQgdG8gZW5kb3JzZSBvciBwcm9tb3RlIHByb2R1
Y3RzCiAgICAgIGRlcml2ZWQgZnJvbSB0aGlzIHNvZnR3YXJlIHdpdGhvdXQgc3BlY2lmaWMgcHJp
b3Igd3JpdHRlbiBwZXJtaXNzaW9uLgoKVEhJUyBTT0ZUV0FSRSBJUyBQUk9WSURFRCBCWSBUSEUg
Q09QWVJJR0hUIEhPTERFUlMgQU5EIENPTlRSSUJVVE9SUyAiQVMgSVMiIEFORApBTlkgRVhQUkVT
UyBPUiBJTVBMSUVEIFdBUlJBTlRJRVMsIElOQ0xVRElORywgQlVUIE5PVCBMSU1JVEVEIFRPLCBU
SEUgSU1QTElFRApXQVJSQU5USUVTIE9GIE1FUkNIQU5UQUJJTElUWSBBTkQgRklUTkVTUyBGT1Ig
QSBQQVJUSUNVTEFSIFBVUlBPU0UgQVJFCkRJU0NMQUlNRUQuIElOIE5PIEVWRU5UIFNIQUxMIDxD
T1BZUklHSFQgSE9MREVSPiBCRSBMSUFCTEUgRk9SIEFOWQpESVJFQ1QsIElORElSRUNULCBJTkNJ
REVOVEFMLCBTUEVDSUFMLCBFWEVNUExBUlksIE9SIENPTlNFUVVFTlRJQUwgREFNQUdFUwooSU5D
TFVESU5HLCBCVVQgTk9UIExJTUlURUQgVE8sIFBST0NVUkVNRU5UIE9GIFNVQlNUSVRVVEUgR09P
RFMgT1IgU0VSVklDRVM7CkxPU1MgT0YgVVNFLCBEQVRBLCBPUiBQUk9GSVRTOyBPUiBCVVNJTkVT
UyBJTlRFUlJVUFRJT04pIEhPV0VWRVIgQ0FVU0VEIEFORApPTiBBTlkgVEhFT1JZIE9GIExJQUJJ
TElUWSwgV0hFVEhFUiBJTiBDT05UUkFDVCwgU1RSSUNUIExJQUJJTElUWSwgT1IgVE9SVAooSU5D
TFVESU5HIE5FR0xJR0VOQ0UgT1IgT1RIRVJXSVNFKSBBUklTSU5HIElOIEFOWSBXQVkgT1VUIE9G
IFRIRSBVU0UgT0YgVEhJUwpTT0ZUV0FSRSwgRVZFTiBJRiBBRFZJU0VEIE9GIFRIRSBQT1NTSUJJ
TElUWSBPRiBTVUNIIERBTUFHRS4K""",
  "pubspec.yaml",
  "text",
  """bmFtZToge3twcm9qZWN0TmFtZX19CnZlcnNpb246IDAuMC4xCmRlc2NyaXB0aW9uOiBBIG1pbmlt
YWwgY29tbWFuZC1saW5lIGFwcGxpY2F0aW9uLgojYXV0aG9yOiBGaXJzdCBMYXN0IDxlbWFpbEBl
eGFtcGxlLmNvbT4KI2hvbWVwYWdlOiBodHRwczovL3d3dy5leGFtcGxlLmNvbQplbnZpcm9ubWVu
dDoKICBzZGs6ICc+PTEuMC4wIDwyLjAuMCcKI2RlcGVuZGVuY2llczoKIyAgZm9vX2JhcjogJz49
MS4wLjAgPDIuMC4wJwpkZXZfZGVwZW5kZW5jaWVzOgogIHVuaXR0ZXN0OiBhbnkK""",
  "README.md",
  "text",
  "IyB7e3Byb2plY3ROYW1lfX0KCkEgbWluaW1hbCBjb21tYW5kLWxpbmUgYXBwbGljYXRpb24uCg==",
  "test/all.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uIEFsbCByaWdodHMgcmVzZXJ2
ZWQuIFVzZSBvZiB0aGlzIHNvdXJjZSBjb2RlCi8vIGlzIGdvdmVybmVkIGJ5IGEgQlNELXN0eWxl
IGxpY2Vuc2UgdGhhdCBjYW4gYmUgZm91bmQgaW4gdGhlIExJQ0VOU0UgZmlsZS4KCmxpYnJhcnkg
YWxsX3Rlc3RzOwoKaW1wb3J0ICd7e3Byb2plY3ROYW1lfX1fdGVzdC5kYXJ0JyBhcyB7e3Byb2pl
Y3ROYW1lfX1fdGVzdDsKCnZvaWQgbWFpbigpIHsKICB7e3Byb2plY3ROYW1lfX1fdGVzdC5kZWZp
bmVUZXN0cygpOwp9Cg==""",
  "test/projectName_test.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uIEFsbCByaWdodHMgcmVzZXJ2
ZWQuIFVzZSBvZiB0aGlzIHNvdXJjZSBjb2RlCi8vIGlzIGdvdmVybmVkIGJ5IGEgQlNELXN0eWxl
IGxpY2Vuc2UgdGhhdCBjYW4gYmUgZm91bmQgaW4gdGhlIExJQ0VOU0UgZmlsZS4KCmxpYnJhcnkg
e3twcm9qZWN0TmFtZX19X3Rlc3Q7CgppbXBvcnQgJ3BhY2thZ2U6e3twcm9qZWN0TmFtZX19L3t7
cHJvamVjdE5hbWV9fS5kYXJ0JzsKaW1wb3J0ICdwYWNrYWdlOnVuaXR0ZXN0L3VuaXR0ZXN0LmRh
cnQnOwoKdm9pZCBtYWluKCkgPT4gZGVmaW5lVGVzdHMoKTsKCnZvaWQgZGVmaW5lVGVzdHMoKSB7
CiAgZ3JvdXAoJ21haW4gdGVzdHMnLCAoKSB7CiAgICB0ZXN0KCdjYWxjdWxhdGUnLCAoKSB7CiAg
ICAgIGV4cGVjdChjYWxjdWxhdGUoKSwgNDIpOwogICAgfSk7CiAgfSk7Cn0K"""
];

==> stagehand-0.1.2.tar.gz: lib/generators/consoleapp_data.dart <==
// Copyright (c) 2014, Google Inc. Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

List<String> data = [
  ".gitignore",
  "text",
  "LkRTX1N0b3JlCi5pZGVhCi5wdWIvCmJ1aWxkLwpwYWNrYWdlcwpwdWJzcGVjLmxvY2sK",
  "bin/main.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uIEFsbCByaWdodHMgcmVzZXJ2
ZWQuIFVzZSBvZiB0aGlzIHNvdXJjZSBjb2RlCi8vIGlzIGdvdmVybmVkIGJ5IGEgQlNELXN0eWxl
IGxpY2Vuc2UgdGhhdCBjYW4gYmUgZm91bmQgaW4gdGhlIExJQ0VOU0UgZmlsZS4KCmltcG9ydCAn
cGFja2FnZTp7e3Byb2plY3ROYW1lfX0ve3twcm9qZWN0TmFtZX19LmRhcnQnIGFzIHt7cHJvamVj
dE5hbWV9fTsKCm1haW4oKSB7CiAgcHJpbnQoJ0hlbGxvIHdvcmxkOiAke3t7cHJvamVjdE5hbWV9
fS5jYWxjdWxhdGUoKX0nKTsKfQo=""",
  "CHANGELOG.md",
  "text",
  """IyBDaGFuZ2Vsb2cKCiMjIDAuMC4xCgoqIEluaXRpYWwgdmVyc2lvbiwgY3JlYXRlZCBieSBTdGFn
ZWhhbmQuCg==""",
  "lib/projectName.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uIEFsbCByaWdodHMgcmVzZXJ2
ZWQuIFVzZSBvZiB0aGlzIHNvdXJjZSBjb2RlCi8vIGlzIGdvdmVybmVkIGJ5IGEgQlNELXN0eWxl
IGxpY2Vuc2UgdGhhdCBjYW4gYmUgZm91bmQgaW4gdGhlIExJQ0VOU0UgZmlsZS4KCi8vLyBUaGUg
e3twcm9qZWN0TmFtZX19IGxpYnJhcnkuCmxpYnJhcnkge3twcm9qZWN0TmFtZX19OwoKaW50IGNh
bGN1bGF0ZSgpIHsKICByZXR1cm4gNiAqIDc7Cn0K""",
  "LICENSE",
  "text",
  """Q29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uCkFsbCByaWdodHMgcmVzZXJ2ZWQu
CgpSZWRpc3RyaWJ1dGlvbiBhbmQgdXNlIGluIHNvdXJjZSBhbmQgYmluYXJ5IGZvcm1zLCB3aXRo
IG9yIHdpdGhvdXQKbW9kaWZpY2F0aW9uLCBhcmUgcGVybWl0dGVkIHByb3ZpZGVkIHRoYXQgdGhl
IGZvbGxvd2luZyBjb25kaXRpb25zIGFyZSBtZXQ6CiAgICAqIFJlZGlzdHJpYnV0aW9ucyBvZiBz
b3VyY2UgY29kZSBtdXN0IHJldGFpbiB0aGUgYWJvdmUgY29weXJpZ2h0CiAgICAgIG5vdGljZSwg
dGhpcyBsaXN0IG9mIGNvbmRpdGlvbnMgYW5kIHRoZSBmb2xsb3dpbmcgZGlzY2xhaW1lci4KICAg
ICogUmVkaXN0cmlidXRpb25zIGluIGJpbmFyeSBmb3JtIG11c3QgcmVwcm9kdWNlIHRoZSBhYm92
ZSBjb3B5cmlnaHQKICAgICAgbm90aWNlLCB0aGlzIGxpc3Qgb2YgY29uZGl0aW9ucyBhbmQgdGhl
IGZvbGxvd2luZyBkaXNjbGFpbWVyIGluIHRoZQogICAgICBkb2N1bWVudGF0aW9uIGFuZC9vciBv
dGhlciBtYXRlcmlhbHMgcHJvdmlkZWQgd2l0aCB0aGUgZGlzdHJpYnV0aW9uLgogICAgKiBOZWl0
aGVyIHRoZSBuYW1lIG9mIHRoZSA8b3JnYW5pemF0aW9uPiBub3IgdGhlCiAgICAgIG5hbWVzIG9m
IGl0cyBjb250cmlidXRvcnMgbWF5IGJlIHVzZWQgdG8gZW5kb3JzZSBvciBwcm9tb3RlIHByb2R1
Y3RzCiAgICAgIGRlcml2ZWQgZnJvbSB0aGlzIHNvZnR3YXJlIHdpdGhvdXQgc3BlY2lmaWMgcHJp
b3Igd3JpdHRlbiBwZXJtaXNzaW9uLgoKVEhJUyBTT0ZUV0FSRSBJUyBQUk9WSURFRCBCWSBUSEUg
Q09QWVJJR0hUIEhPTERFUlMgQU5EIENPTlRSSUJVVE9SUyAiQVMgSVMiIEFORApBTlkgRVhQUkVT
UyBPUiBJTVBMSUVEIFdBUlJBTlRJRVMsIElOQ0xVRElORywgQlVUIE5PVCBMSU1JVEVEIFRPLCBU
SEUgSU1QTElFRApXQVJSQU5USUVTIE9GIE1FUkNIQU5UQUJJTElUWSBBTkQgRklUTkVTUyBGT1Ig
QSBQQVJUSUNVTEFSIFBVUlBPU0UgQVJFCkRJU0NMQUlNRUQuIElOIE5PIEVWRU5UIFNIQUxMIDxD
T1BZUklHSFQgSE9MREVSPiBCRSBMSUFCTEUgRk9SIEFOWQpESVJFQ1QsIElORElSRUNULCBJTkNJ
REVOVEFMLCBTUEVDSUFMLCBFWEVNUExBUlksIE9SIENPTlNFUVVFTlRJQUwgREFNQUdFUwooSU5D
TFVESU5HLCBCVVQgTk9UIExJTUlURUQgVE8sIFBST0NVUkVNRU5UIE9GIFNVQlNUSVRVVEUgR09P
RFMgT1IgU0VSVklDRVM7CkxPU1MgT0YgVVNFLCBEQVRBLCBPUiBQUk9GSVRTOyBPUiBCVVNJTkVT
UyBJTlRFUlJVUFRJT04pIEhPV0VWRVIgQ0FVU0VEIEFORApPTiBBTlkgVEhFT1JZIE9GIExJQUJJ
TElUWSwgV0hFVEhFUiBJTiBDT05UUkFDVCwgU1RSSUNUIExJQUJJTElUWSwgT1IgVE9SVAooSU5D
TFVESU5HIE5FR0xJR0VOQ0UgT1IgT1RIRVJXSVNFKSBBUklTSU5HIElOIEFOWSBXQVkgT1VUIE9G
IFRIRSBVU0UgT0YgVEhJUwpTT0ZUV0FSRSwgRVZFTiBJRiBBRFZJU0VEIE9GIFRIRSBQT1NTSUJJ
TElUWSBPRiBTVUNIIERBTUFHRS4K""",
  "pubspec.yaml",
  "text",
  """bmFtZToge3twcm9qZWN0TmFtZX19CnZlcnNpb246IDAuMC4xCmRlc2NyaXB0aW9uOiBBIG1pbmlt
YWwgY29tbWFuZC1saW5lIGFwcGxpY2F0aW9uLgojYXV0aG9yOiBGaXJzdCBMYXN0IDxlbWFpbEBl
eGFtcGxlLmNvbT4KI2hvbWVwYWdlOiBodHRwczovL3d3dy5leGFtcGxlLmNvbQplbnZpcm9ubWVu
dDoKICBzZGs6ICc+PTEuMC4wIDwyLjAuMCcKI2RlcGVuZGVuY2llczoKIyAgZm9vX2JhcjogJz49
MS4wLjAgPDIuMC4wJwpkZXZfZGVwZW5kZW5jaWVzOgogIHVuaXR0ZXN0OiBhbnkK""",
  "README.md",
  "text",
  "IyB7e3Byb2plY3ROYW1lfX0KCkEgbWluaW1hbCBjb21tYW5kLWxpbmUgYXBwbGljYXRpb24uCg==",
  "test/all.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uIEFsbCByaWdodHMgcmVzZXJ2
ZWQuIFVzZSBvZiB0aGlzIHNvdXJjZSBjb2RlCi8vIGlzIGdvdmVybmVkIGJ5IGEgQlNELXN0eWxl
IGxpY2Vuc2UgdGhhdCBjYW4gYmUgZm91bmQgaW4gdGhlIExJQ0VOU0UgZmlsZS4KCmxpYnJhcnkg
YWxsX3Rlc3RzOwoKaW1wb3J0ICd7e3Byb2plY3ROYW1lfX1fdGVzdC5kYXJ0JyBhcyB7e3Byb2pl
Y3ROYW1lfX1fdGVzdDsKCnZvaWQgbWFpbigpIHsKICB7e3Byb2plY3ROYW1lfX1fdGVzdC5kZWZp
bmVUZXN0cygpOwp9Cg==""",
  "test/projectName_test.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSB7e3llYXJ9fSwgPHlvdXIgbmFtZT4uIEFsbCByaWdodHMgcmVzZXJ2
ZWQuIFVzZSBvZiB0aGlzIHNvdXJjZSBjb2RlCi8vIGlzIGdvdmVybmVkIGJ5IGEgQlNELXN0eWxl
IGxpY2Vuc2UgdGhhdCBjYW4gYmUgZm91bmQgaW4gdGhlIExJQ0VOU0UgZmlsZS4KCmxpYnJhcnkg
e3twcm9qZWN0TmFtZX19X3Rlc3Q7CgppbXBvcnQgJ3BhY2thZ2U6e3twcm9qZWN0TmFtZX19L3t7
cHJvamVjdE5hbWV9fS5kYXJ0JzsKaW1wb3J0ICdwYWNrYWdlOnVuaXR0ZXN0L3VuaXR0ZXN0LmRh
cnQnOwoKdm9pZCBtYWluKCkgPT4gZGVmaW5lVGVzdHMoKTsKCnZvaWQgZGVmaW5lVGVzdHMoKSB7
CiAgZ3JvdXAoJ21haW4gdGVzdHMnLCAoKSB7CiAgICB0ZXN0KCdjYWxjdWxhdGUnLCAoKSB7CiAg
ICAgIGV4cGVjdChjYWxjdWxhdGUoKSwgNDIpOwogICAgfSk7CiAgfSk7Cn0K"""
];
